
'use strict';

/**
 * 这是一个内部模块. FinoChatBaseApis 目前仅用于 {@link client~FinoChatClient}.
 *
 * @module base-apis
 */

var utils = require('./utils');
var log = require('./log');
var JSBridge = require('./jsbridge');

/**
 * FinoChat JS-SDK APIs
 *
 * @constructor
 *
 * @param {Object} opts 配置参数
 * @param {string} opts.appKey Required. FinoChatSDK 的AppKey
 */
function FinoChatBaseApis(opts) {
    utils.checkObjectHasKeys(opts, ['appKey']);
    this.jsBridge = new JSBridge();
    log.debug('DEBUG: JSBridge', this.jsBridge);
}

/**
 * 调用自定义方法
 * @param {string} handler 方法名
 * @param {Object} opts 参数
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.callHandler = function (handler, opts, callback) {
    this.jsBridge.getJSBridge().callHandler(handler, opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 注册自定义方法
 * @param {string} handler 注册方法名
 * @param {string} callbackName 回调方法名
 * @param {Object} responseData 返回数据
 * @return {void}
 */
FinoChatBaseApis.prototype.registerHandler = function (handler, callbackName, responseData) {
    this.jsBridge.getJSBridge().registerHandler(handler, function (data, responseCallback) {
        var callback = callbackName ? callbackName : handler + 'Callback';
        window[callback] && window[callback](data);
        responseCallback && responseCallback(responseData);
    });
};

/**
 * 用户密码登陆
 * @param {string} user
 * @param {string} password
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.loginWithPassword = function (user, password, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_loginWithPassword', { 'username': user, 'password': password }, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * TOKEN登陆
 * @param {string} token
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.loginWithToken = function (token, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_loginWithToken', { 'token': token }, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 身份证识别
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.scanIDCard = function (callback) {
    this.jsBridge.getJSBridge().callHandler('fin_scanIDCard', {}, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 银行卡识别
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.scanBankCard = function (callback) {
    this.jsBridge.getJSBridge().callHandler('fin_scanBankCard', {}, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 打开会话列表
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.openConversation = function (callback) {
    this.jsBridge.getJSBridge().callHandler('fin_openConversation', {}, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 打开聊天房间
 * @param {string} roomId Required. 房间ID
 * @param {string} displayName Required. 房间展示名称（兼容iOS）
 * @param {module:client.callback} callback Optional.
 * @return {void}
 */
FinoChatBaseApis.prototype.openRoomWithRoomId = function (roomId, displayName, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_openRoomWithRoomId', { 'roomId': roomId, 'displayName': displayName }, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 选择图片(暂未实现)
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.chooseImage = function (opts, callback) {};

/**
 * 预览图片
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.previewImage = function (opts, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_openPhotoBrowser', opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 上传图片(暂未实现)
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.uploadImage = function (opts, callback) {};

/**
 * 取本地图片
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.getLocalImgData = function (opts, callback) {};

/**
 * 配置导航栏
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.configNavigationBar = function (opts, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_configNavigationBar', opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 新打开webView
 * @param {string} url Required. webView完整url
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.openWebView = function (url, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_openWebView', { 'url': url }, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 关闭当前webView
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.closeWebView = function (callback) {
    this.jsBridge.getJSBridge().callHandler('fin_closeWebView', {}, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 获取用户登陆session
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.getSession = function (callback) {
    this.jsBridge.getJSBridge().callHandler('fin_getSession', {}, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 转发到聊天房间
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.forwardToRoom = function (opts, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_forwardToRoom', opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 聊天发送投资组合(长城业务接口)
 * @param {Object}  opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.sendPortfolio = function (opts, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_sendPortfolio', opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * 显示遮罩层
 * @param {Object} opts.
 * @param {module:client.callback} callback Optional.
 */
FinoChatBaseApis.prototype.showModal = function (opts, callback) {
    this.jsBridge.getJSBridge().callHandler('fin_showModal', opts, function (response) {
        callback(utils.parseResponse(response));
    });
};

/**
 * FinoChatBaseApis object
 */
module.exports = FinoChatBaseApis;
//# sourceMappingURL=base-apis.js.map